@@ -1,8 +1,8 @@
-fortify.bathy <- function(x, ...) {
+fortify.bathy <- function(model, data, ...) {
   # Convert an object of class bathy into a data.frame, for ggplot
   # x   object of class bathy
 
-  x <- as.xyz(x)
+  x <- as.xyz(model)
   names(x) <- c("x", "y", "z")
   return(x)
 }
\ No newline at end of file
